#!/usr/bin/env python

import core.Plugin as Plugin
import core.VersionHelper as VersionHelper
import os
import zipfile

M_LF         = chr(10)
M_QUOTE      = chr(39)

class BuildPlugin(Plugin.Plugin):
  def __init__(self):
    Plugin.Plugin.__init__(self)
    self.setType("BUILD")
    
    self.addParameterDefinition('version',['-v','--version'])

  def getPluginDir(self):
    return self.getNooraDir()+os.sep+'plugins'+os.sep+'component'+os.sep+'build'

  def getDescription(self):
    return "creates a database independend component."


  def getUsage(self):
    print "NoOra database installer, build.py"
    print self.getDescription()
    print "-v= --version=  required, the version to build"

  def getDefaultVersion(self):
    configReader=self.getConfigReader()
    defaultVersion=configReader.getValue('DEFAULT_VERSION')
    return defaultVersion
  
  def getVersions(self, defaultVersion):
    projectHelper=self.getProjectHelper()    
    versions=[]
    alterFolder=projectHelper.getAlterFolder()
    if projectHelper.folderPresent(alterFolder):
      versions=projectHelper.findFolders(alterFolder)
    createFolder=projectHelper.getCreateFolder()
    if projectHelper.folderPresent(createFolder):
      versions.append(defaultVersion)
    versionHelper=VersionHelper.VersionHelper(versions)
    versions=versionHelper.sort()
    return versions  

  def isFileExcluded(self, filename):
    configReader=self.getConfigReader()
    excludedFiles=configReader.getValue('COMPONENT_EXCLUDED_FILES')
    for excludedFile in excludedFiles:
      if filename.lower()==excludedFile.lower():
        return True
    return False
  
  def getSqlVersionStatement(self, versions, version, componentName):
    configReader=self.getConfigReader()
    createVersion=versions[0]
    if createVersion==version:
      stream=configReader.getValue('COMPONENT_INSERT_STATEMENT')
    else:
      stream=configReader.getValue('COMPONENT_UPDATE_STATEMENT')
    stream=stream.replace('<version>',version)
    stream=stream.replace('<name>',componentName)
    return stream


  def execute(self, parameterHelper):
    if parameterHelper.hasParameter('-h'):
      self.getUsage()
      exit(1)

    projectHelper=self.getProjectHelper()
    configReader=self.getConfigReader()

    version=parameterHelper.getParameterValue(['-v=','--version='],[])
    projectHelper.failOnEmpty(version,'no version was given')

    defaultVersion = self.getDefaultVersion()
    projectHelper.failOnNone(defaultVersion,'the variable DEFAULT_VERSION is not set.')

    componentName=configReader.getValue('COMPONENT_NAME')
    projectHelper.failOnNone(componentName,'the variable COMPONENT_NAME is not set.')

    componentSelectStatement=configReader.getValue('COMPONENT_SELECT_STATEMENT')
    projectHelper.failOnNone(componentSelectStatement,'the variable COMPONENT_SELECT_STATEMENT is not set.')


    componentTargetFolder=configReader.getValue('COMPONENT_TARGET_FOLDER')
    projectHelper.failOnNone(componentTargetFolder,'the variable COMPONENT_TARGET_FOLDER is not set.')
    targetFolder = self.getBaseDir() + os.sep + componentTargetFolder

    componentExcludedFiles=configReader.getValue('COMPONENT_EXCLUDED_FILES')
    projectHelper.failOnNone(componentExcludedFiles,'the variable COMPONENT_EXCLUDED_FILES is not set.')
        
    schemes=configReader.getValue('SCHEMES')
    projectHelper.failOnNone(schemes,'the variable SCHEMES is not set.')
        
    objects = configReader.getValue('CREATE_OBJECTS')
    projectHelper.failOnNone(schemes,'the variable CREATE_OBJECTS is not set.')


    # find the versions
    versions=self.getVersions(defaultVersion)
    version=version[0]
    projectHelper.failOnValueNotFound(versions,version,'the given version is not valid for this project.')

    buildFolder=projectHelper.getBuildFolder(versions, version)
    projectHelper.invalidBuildFolder(buildFolder)

    print "building component with version '"+version+"'"

    # compress the build
    if projectHelper.folderNotPresent(targetFolder):
      os.makedirs(targetFolder)
  
    zipUrl=targetFolder + os.sep + componentName + '_' + version + '.zip'
    zipHandle=zipfile.ZipFile(zipUrl,'w')

    for scheme in schemes:

      for object in objects:

        # global ddl objects
        folder=buildFolder+os.sep+scheme+os.sep+'ddl'+os.sep+object
        zipFolder=componentName + '_' + version + os.sep + 'ddl' + os.sep + object + os.sep
        if projectHelper.folderPresent(folder):
          if folder.endswith('lib')==False:
            files=projectHelper.findFiles(folder)
            for file in files:
              sourceFile=folder+os.sep+file
              targetFile=zipFolder+file
              zipHandle.write(sourceFile,targetFile,zipfile.ZIP_DEFLATED)

  
      # global dat files
      folder=buildFolder+os.sep+scheme+os.sep+'dat'
      zipFolder=componentName+'_'+version+os.sep+'dat'+os.sep
      
      if projectHelper.folderPresent(folder):
        files=projectHelper.findFiles(folder)
        for file in files:        
          if self.isFileExcluded(file)==False:
            sourceFile=folder+os.sep+file
            targetFile=zipFolder+file
            zipHandle.write(sourceFile,targetFile,zipfile.ZIP_DEFLATED)

    # create the version script in the dat folder      
    stream=self.getSqlVersionStatement(versions, version, componentName)
    filename="version.sql"
    sourceFile=targetFolder+os.sep+filename
    projectHelper.writeFile(sourceFile,stream)

    zipFolder=componentName+'_'+version+os.sep+'dat'+os.sep
    targetFile=zipFolder+filename

    zipHandle.write(sourceFile,targetFile,zipfile.ZIP_DEFLATED)
    os.remove(sourceFile)

    

    # add template files
    folder=self.getPluginDir()+os.sep+'templates'
    zipFolder=componentName+'_'+version+os.sep
    if projectHelper.folderPresent(folder):
      files=projectHelper.findFiles(folder)
      for file in files:
        sourceFile=folder+os.sep+file
        targetFile=zipFolder+file
        zipHandle.write(sourceFile,targetFile,zipfile.ZIP_DEFLATED)

    # create and add component.conf
    filename="component.conf"
    sourceFile=targetFolder+os.sep+filename

    lines=[]
    lines.append('COMPONENT_NAME='+M_QUOTE+componentName+M_QUOTE)
    lines.append('COMPONENT_VERSION='+M_QUOTE+version+M_QUOTE)
    lines.append('COMPONENT_SELECT_STATEMENT='+'"'+componentSelectStatement+'"')
    lines.append('COMPONENT_VERSIONS='+str(versions))
    stream = M_LF.join(lines)
    stream=stream.replace('<name>',componentName)
    projectHelper.writeFile(sourceFile,stream)

    zipFolder=componentName+'_'+version+os.sep
    targetFile=zipFolder+filename

    zipHandle.write(sourceFile,targetFile,zipfile.ZIP_DEFLATED)
    os.remove(sourceFile)

    zipHandle.close()
    print "component for version "+version+" created."




#!/usr/bin/env python

import os
import sys
import zipfile
import platform
import subprocess
import core.NooraException as NooraException

# 'constant' to determine if we're on the cyswin platform
ON_CYGWIN=platform.system().lower().find("cygwin") == -1;

class ProjectHelper:

  def __init__(self, configReader):
    self.__configReader=configReader
    self.setBaseDir(os.path.abspath('.'))
    self.setNooraDir(os.path.abspath(os.path.dirname(sys.argv[0])))

  def setConfigReader(self,configReader):
    self.__configReader=configReader

  def setBaseDir(self, path):
    self.__baseDir=path

  def getBaseDir(self):
    return self.__baseDir

  def setNooraDir(self,path):
    self.__nooraDir=path

  def getNooraDir(self):
    return self.__nooraDir

  def getScriptDir(self):
    return self.getNooraDir()+os.sep+'scripts'


  def fileNotPresent(self, url):
    if os.path.isfile(url):
      return False
    return True


  def folderNotPresent(self, folder):
    if os.path.isdir(folder):
      return False
    return True

  def folderPresent(self, folder):
    if os.path.isdir(folder):
      return True
    return False


  def findTemplateFile(self, filename):
    baseDir=self.getBaseDir()
    url=baseDir+os.sep+filename
    if os.path.isfile(url):
      return url
    url=self.getNooraDir()+os.sep+filename
    if os.path.isfile(url):
      return url
    url=self.GetScriptDir()+os.sep+filename
    if os.path.isfile(url):
      return url
    return None

  def getAlterFolder(self):
    baseDir=self.getBaseDir()
    alterFolder=baseDir+os.sep+'alter'
    return alterFolder

  def getCreateFolder(self):
    baseDir=self.getBaseDir()
    createFolder=baseDir+os.sep+'create'
    return createFolder

  def getBuildFolder(self, versions, version):
    createVersion=versions[0]
    baseDir=self.getBaseDir()
    if createVersion==version:
      buildFolder=baseDir+os.sep+'create'
    else:
      buildFolder=baseDir+os.sep+'alter'+os.sep+version
    return buildFolder

  # deprecated, use failOnFolderNotPresent instead.
  def invalidBuildFolder(self, buildFolder):
    if self.folderNotPresent(buildFolder):
      raise NooraException.NooraException('build folder is not present.')

  def failOnEmpty(self, values, message):
    if len(values)==0:
      raise NooraException.NooraException(message)

  def failOnFolderNotPresent(self, folder, message):
    if self.folderNotPresent(folder):
      raise NooraException.NooraException(message)

  def failOnFolderPresent(self, folder, message):
    if self.folderPresent(folder):
      raise NooraException.NooraException(message)

  def failOnNone(self, value, message):
    if value==None:
      raise NooraException.NooraException(message)

  def failOnFileNotPresent(self, url, message):
    if self.fileNotPresent(url):
      raise NooraException.NooraException(message)

  def hasValue(self, list, value):
    for item in list:
      if item==value:
        return True
    return False

  def failOnValueNotFound(self, list, value, message):
    if self.hasValue(list, value)==False:
      raise NooraException.NooraException(message)

  def getMysqlUser(self, mysqlHost, database):
    users=self.__configReader.getValue('MYSQL_USERS')
    for user in users:
      if user[0].lower()==mysqlHost.lower() and user[1].lower()==database.lower():
        return user[2]
    return None
  
  def getMysqlPasswd(self, mysqlHost, database):
    users=self.__configReader.getValue('MYSQL_USERS')
    for user in users:
      if user[0].lower()==mysqlHost.lower() and user[1].lower()==database.lower():
        return user[3]
    return None


  def getOracleUser(self, oracleSid, scheme):
    users=self.__configReader.getValue('ORACLE_USERS')
    for user in users:
      if user[0].lower()==oracleSid.lower() and user[1].lower()==scheme.lower():
        return user[2]
    return None




  def getOraclePasswd(self, oracleSid, scheme):
    users=self.__configReader.getValue('ORACLE_USERS')
    for user in users:
      if user[0].lower()==oracleSid.lower() and user[1].lower()==scheme.lower():
        return user[3]
    return None


  def readFile(self, filename):
    handle=open(filename,'rb')
    stream=handle.read()
    handle.close()
    return stream


  def writeFile(self, filename,stream):
    handle=open(filename,'wb')
    handle.write(stream)
    handle.close()


  def copyFile(self, fromUrl, toUrl):
    stream=self.readFile(fromUrl)
    self.writeFile(toUrl,stream)


  def extractFile(self, url, subFolder=None):
    folder=self.getFolder(url)
    file=zipfile.ZipFile(url,'r')
    for info in file.infolist():
      stream=file.read(info.filename)
      extractUrl=folder+os.sep+info.filename
      if subFolder:
        extractUrl=folder+os.sep+subFolder+os.sep+info.filename
      extractFolder=self.getFolder(extractUrl)
      if self.folderNotPresent(extractFolder):
        os.makedirs(extractFolder)
      self.writeFile(extractUrl,stream)


  def getFilename(self, url):
    folder,filename=os.path.split(url)
    return filename


  def getFileExtension(self, url):
    root,ext=os.path.splitext(url)
    return ext.lstrip('.')

  def getFileRoot(self, url):
    root,ext=os.path.splitext(url)
    return root

  def getFolder(self, url):
    folder,filename=os.path.split(url)
    return folder


  def isFileExcluded(self, url):
    excludedFiles=self.__configReader.getValue('EXCLUDED_FILES')
    self.failOnNone(excludedFiles,'the variable EXCLUDED_FILES is not set.')
    for excludedFile in excludedFiles:
      if self.getFilename(url).lower()==excludedFile.lower():
        return True

    excludedExtensions=self.__configReader.getValue('EXCLUDED_EXTENSIONS')
    self.failOnNone(excludedExtensions,'the variable EXCLUDED_EXTENSIONS is not set.')
    for excludedExtension in excludedExtensions:
      if self.getFileExtension(url)==excludedExtension:
        return True
    return False


  def findFiles(self, folder):
    result=[]
    if os.path.isdir(folder):
      files=os.listdir(folder)
      for file in files:
        url=folder+os.sep+file
        if os.path.isfile(url):
          if self.isFileExcluded(url)==False:
            result.append(file)
      result.sort()
    return result


  def findFilesRecursive(self, folder):
    result=[]
    files=os.listdir(folder)
    for file in files:
      url=folder+os.sep+file
      if os.path.isdir(url):
        subFiles=self.findFilesRecursive(url)
        for subFile in subFiles:
          result.append(subFile)
      else:
        result.append(url)
    return result


  def isFolderExcluded(self, folder):
    excludedFolders=self.__configReader.getValue('EXCLUDED_FOLDERS')
    for excludedFolder in excludedFolders:
      if folder.lower()==excludedFolder.lower():
        return True
    return False


  def findFolders(self, folder):
    result=[]
    items=os.listdir(folder)
    for item in items:
      if os.path.isdir(folder+os.sep+item):
        if self.isFolderExcluded(item)==False:
          result.append(item)
    result.sort()
    return result

  def findFoldersRecursive(self, path):
    result=[]
    folders=os.listdir(path)
    for folder in folders:
      if os.path.isdir(path+os.sep+folder):
        result.append(path+os.sep+folder)
        subFolders=self.findFoldersRecursive(path+os.sep+folder)
        for subFolder in subFolders:
          result.append(subFolder)
    return result


  def removeFolderRecursive(self, path):
    files=self.findFilesRecursive(path)
    for file in files:
      os.remove(file)

    folders=self.findFoldersRecursive(path)
    folders.reverse()
    for folder in folders:
      os.rmdir(folder)

    os.rmdir(path)

  # if we're on cygwin: change cygwin path to windows path
  # so we can use it as a command line param for windows programs (e.g. sqlplus)
  # (exec.. so pretty expensive :-( )
  def cleanPath(self, path):
    if ON_CYGWIN:
      return path
    else:
      proc = subprocess.Popen(["cygpath -wa "+ path], stdout=subprocess.PIPE, shell=True);
      (out, err) = proc.communicate();
      result = out.rstrip();

    return result;








#!/usr/bin/env python
from org.noora.io.Filterable import Filterable

class FileExtensionFilter(Filterable):

  def __init__(self, file):
    Filterable.__init__(self)
    self.__file = file
    
  def getFile(self):
    return self.__file
    
  def accept(self, fileable):
    file = self.getFile()
   
    if fileable.getExtension()==file.getExtension():
      return True
    return False
       





#!/usr/bin/env python

import sys

class ParameterHelper:
  
  def __init__(self):
    self.__parameters=[]
    self.setParameters()

  def setParameters(self):
    for param in sys.argv:
      self.__parameters.append(param)

  def getParameters(self):
    return self.__parameters

  def hasParameter(self, parameter):
    for param in self.__parameters:
      if param==parameter:
        return True
    return False

  def findParameter(self, parameters,p):
    result=None
    for parameter in parameters:
      if parameter.find(p)!=-1:
        result=parameter
        break
    return result

  def getParameter(self, keyword):
    for param in self.__parameters:
      if param.find(keyword)!=-1:        
        return param
    return None

  def getParameterValue(self, keywords, defaultValue):
    result=[]
    for keyword in keywords:
      parameter=self.getParameter(keyword)
      if parameter:
        result.append(parameter.split('=')[1])

    if len(result)==0:    
      return defaultValue

    return result









#!/usr/bin/env python
import sys
import os
import subprocess


import ComponentHelper   as ComponentHelper
import ConfigReader      as ConfigReader
import ParameterHelper   as ParameterHelper
import NooraException    as NooraException

OBJECTS        = ['usr','dbl','dir','syn','lib','typ','scm','aq','seq','tab','cst','fct','prc','pkg','jar','mvw','vw','trg','idx','gra']
BASE_DIR       = os.path.abspath(os.path.dirname(sys.argv[0]))
SILENTMODE     = False


def getUsage():
  print "NoOra database installer, setup.py"
  print "installs a database independend component."
  print "-s= --sid=     required contains the tnsname of the database."
  print "-u= --username=  required, contains the username."
  print "-p= --password=  required, contains the password."
  print "-silent          not required, disables the execution output."


def showErrors(componentHelper):
  try:
    stream=componentHelper.readFile('feedback.log')
    print stream
  except:
    exit(1)


def getPreviousVersion(versions, version):
  index=versions.index(version)
  if index>0:
    previousVersion=versions[index-1]
    return previousVersion    
  return "Nothing"


def executeSqlplus(componentHelper, oracleSid, oracleUser, oraclePasswd, oracleScript, paramA, paramB):
  connectString=oracleUser+'/'+oraclePasswd+'@'+oracleSid
  templateScript='@'+componentHelper.cleanPath(BASE_DIR+os.sep+'setup.sql')
  result=subprocess.call(['sqlplus','-l','-s',connectString , templateScript, componentHelper.cleanPath(oracleScript), paramA, paramB])
  if result!=0:
    showErrors(componentHelper)
    exit(1)

def checkVersion(componentHelper, oracleSid,oracleUser,oraclePasswd,previousVersion, versionSelectStatement):
  oracleScript=BASE_DIR+os.sep+'checkversion.sql'
  executeSqlplus(componentHelper, oracleSid,oracleUser,oraclePasswd, oracleScript,previousVersion,versionSelectStatement)



if __name__ == "__main__":

  try:

    parameterHelper=ParameterHelper.ParameterHelper()   
    if parameterHelper.hasParameter('-h'):
      getUsage()
      exit(1)
      
    if parameterHelper.hasParameter('-silent'):
      SILENTMODE=True      

    componentHelper=ComponentHelper.ComponentHelper()
    configReader=ConfigReader.ConfigReader(BASE_DIR+os.sep+'component.conf')

    oracleSid=parameterHelper.getParameterValue(['-s=','--sid='],[])
    componentHelper.failOnEmpty(oracleSid,'no oracle sid was given')
    oracleSid=oracleSid[0]

    oracleUser=parameterHelper.getParameterValue(['-u=','--username='],[])
    componentHelper.failOnEmpty(oracleUser,'no username was given')
    oracleUser=oracleUser[0]

    oraclePasswd=parameterHelper.getParameterValue(['-p=','--password='],[])
    componentHelper.failOnEmpty(oraclePasswd,'no password was given')
    oraclePasswd=oraclePasswd[0]

    componentName=configReader.getValue('COMPONENT_NAME')
    componentHelper.failOnNone(componentName,'the variable COMPONENT_NAME is not set.')

    componentVersion=configReader.getValue('COMPONENT_VERSION')
    componentHelper.failOnNone(componentName,'the variable COMPONENT_VERSION is not set.')

    componentSelectStatement=configReader.getValue('COMPONENT_SELECT_STATEMENT')
    componentHelper.failOnNone(componentSelectStatement,'the variable COMPONENT_SELECT_STATEMENT is not set.')

    componentVersions=configReader.getValue('COMPONENT_VERSIONS')
    componentHelper.failOnNone(componentVersions,'the variable COMPONENT_VERSIONS is not set.')


    previousVersion=getPreviousVersion(componentVersions,componentVersion)
    checkVersion(componentHelper,oracleSid,oracleUser,oraclePasswd,previousVersion,componentSelectStatement)

    if SILENTMODE==False:
      print "installing component "+componentName+'_'+componentVersion

    for object in OBJECTS:
      
      # ddl objects
      folder=BASE_DIR+os.sep+'ddl'+os.sep+object
      if componentHelper.folderPresent(folder):
        files=componentHelper.findFiles(folder)
        for file in files:
          url=folder+os.sep+file
          if SILENTMODE==False:
            print url.split(BASE_DIR)[1]
          executeSqlplus(componentHelper, oracleSid, oracleUser, oraclePasswd, url, "", "")  

    # global dat files
    folder=BASE_DIR+os.sep+'dat'
    if componentHelper.folderPresent(folder):
      files=componentHelper.findFiles(folder)
      for file in files:
        url=folder+os.sep+file
        if SILENTMODE==False:
          print url.split(BASE_DIR)[1]
        executeSqlplus(componentHelper, oracleSid, oracleUser, oraclePasswd, url, "", "")  

    if SILENTMODE==False:
      print "component "+componentName+'_'+componentVersion+" created."

  except NooraException.NooraException as e:
    print e.getMessage()
    exit(1)



#!/usr/bin/env python
from org.noora.classloader.ClassLoaderException import ClassLoaderException


class ClassLoadable:
    
  def __init__(self):
    pass
    
  def find(self, moduleName, className):
    raise ClassLoaderException("method not implemented") 
    
  def findByPattern(self, pattern):
    raise ClassLoaderException("method not implemented")
    
   
        



#!/usr/bin/env python
from org.noora.io.Loadable import Loadable 
from org.noora.io.File import File
from org.noora.io.FileExtensionFilter import FileExtensionFilter

class ExtensionFilterLoader(Loadable):
  def __init__(self, filters):
    Loadable.__init__(self)
    self.__filters = filters

  def getFilters(self):
    return self.__filters
    
    
  def load(self, list = None, filterType):
    filters = self.getFilters()    
    
    for item  in list:
      file = File(item)
      filter = FileExtensionFilter(file)
      filters.add(filter)

    return filters
  

       





#!/usr/bin/env python
from org.noora.io.IOException import IOException
from org.noora.io.File import File

class FileProvider:
  
  def __init__(self):
    pass
  
  def getFile(self):
    raise IOException("method not implemented")
  

class FileFormat(FileProvider):
  
  def __init__(self, property=None):
    self.__property = property
  
  def getFile(self):
    return File(self.__property.getValue())

class Adaptable:
  def __init__(self):
    pass
  
  def adapt(self):
    raise IOException("method not implemented")
  
class FileFormatAdapter(Adaptable):
  def adapt(self, property=None):
    return FileFormat(property)
          





#!/usr/bin/env python
import core.StreamHelper as StreamHelper
import core.NooraException as NooraException

M_LF = chr(10)

class ConfigReader:

  def __init__(self, filename):
    self.__lines = []
    self.__message = None
    self.__filename = filename
    self.loadFromFile(filename)

  def parse(self, stream):
    stream = StreamHelper.StreamHelper().convert(stream)
    lines = stream.split(chr(10))
    for line in lines:
      self.__lines.append(line)

  def loadFromFile(self, filename):
    try:
      handle = open(filename, 'r')
      stream = handle.read()
      handle.close()
      self.parse(stream)
    except IOError:
      self.setMessage('project configuration file "' + filename + '" not found.')

  def loadFromStream(self, stream):
    self.parse(stream)

  def saveToFile(self, filename):
    stream = M_LF.join(self.__lines)
    handle = open(filename, 'w')
    handle.write(stream)
    handle.close()

  def getValue(self, keyword):
    lines = self.__lines
    for line in lines:
      if line.startswith(keyword):
        values = line.split('=')[1::]
        value = '='.join(values)
        return eval(value)
    return None

  def setValue(self, keyword, value):
    lines = self.__lines
    for line in lines:
      if line.startswith(keyword):
        newLine = keyword + '=' + str(value)
        lines[lines.index(line)] = newLine


  def hasValue(self, keyword, value):
    values = self.getValue(keyword)
    if values != None:
      for val in values:
        if val.lower() == value.lower():
          return True
    return False

  # deprecated, use failOnValueNotFound instead.
  def invalidValue(self, keyword, values):
    for value in values:
      if self.hasValue(keyword, value) == False:
        raise NooraException.NooraException("the given value " + value + " for keyword " + keyword + " is not valid for this project.")

  def failOnValueNotFound(self, keyword, values, message):
    for value in values:
      if self.hasValue(keyword, value) == False:
        raise NooraException.NooraException(message)

  def failOnValueFound(self, keyword, values, message):
    for value in values:
      if self.hasValue(keyword, value) == True:
        raise NooraException.NooraException(message)

  def failOnConfigNotLoaded(self):
    if self.getMessage() != None:
      print self.getMessage()
      exit(1)


  def setMessage(self, message):
    self.__message = message

  def getMessage(self):
    return self.__message

  def getLines(self):
    return self.__lines

  def getFilename(self):
    return self.__filename






#!/usr/bin/env python

from org.noora.processor.Callable import Callable
from org.noora.processor.Processor import Processor

class Call(Callable):
  
  def __init__(self, properties=None):
    Callable.__init__(self)
    self.__properties = properties

  def getProperties(self):
    return self.__properties

  def getProperty(self, key):
    properties = self.getProperties()
    return properties.getPropertyValue(key)
      
    







#!/usr/bin/env python
from org.noora.connector.MysqlExecute import MysqlExecute
from org.noora.connector.OracleExecute import OracleExecute

class ExecuteFactory:
  def __init__(self):
    pass
  
  @staticmethod
  def newMysqlExecute():
    return MysqlExecute()
  
  @staticmethod
  def newOracleExecute():
    return OracleExecute()



#!/usr/bin/env python

import core.Plugin as Plugin
import os


class UnitTestPlugin(Plugin.Plugin):
  def __init__(self):
    Plugin.Plugin.__init__(self)
    self.setType("UNITTEST")
    
    self.addParameterDefinition('database',['-s','-si','--sid'])
    self.addParameterDefinition('scheme',['-u','-sc','--scheme'])
    
  def getDescription(self):
    return "executes unit tests. Uses the noora unit test framework."


  def getUsage(self):  
    print "NoOra database installer, unittest.py."
    print self.getDescription()
    print "remarks : a unit test is always a package. "
    print "          A package containing procedures that start with T_ is considered"
    print "          as a unit test."

    print "-s= --sid=     required contains the tnsname of the database."
    print "-u= --scheme=  not required, contains the scheme of "
    print "               the unit tests to execute."


  def unittest(self, oracleSid, oracleUser, oraclePasswd, ignoreErrors):
    connector=self.getConnector()
    oracleScript=self.getScriptDir()+os.sep+'unittest.sql'
    connector.execute(oracleSid, oracleUser, oraclePasswd, oracleScript,'','',ignoreErrors)


  def execute(self, parameterHelper):
    if parameterHelper.hasParameter('-h'):
      self.getUsage()
      exit(1)    

    ignoreErrors=False  
    if  parameterHelper.hasParameter('-ignore_errors')==True:
      ignoreErrors=True      


    configReader=self.getConfigReader()
    projectHelper=self.getProjectHelper()

    oracleSid=parameterHelper.getParameterValue(['-s=','--sid='],[])
    projectHelper.failOnEmpty(oracleSid,'no oracle sid was given.')
    configReader.failOnValueNotFound('ORACLE_SIDS',oracleSid,'the given oracle sid is not valid for this project.')
    oracleSid=oracleSid[0]
    
    schemes=configReader.getValue('SCHEMES')
    schemes=parameterHelper.getParameterValue(['-u=','--scheme=','--user='],schemes)
    configReader.failOnValueNotFound('SCHEMES',schemes,'the given scheme is not valid for this project.')

    for scheme in schemes:
      print "executing unit tests for scheme '"+scheme+"' in database '"+oracleSid+"'"
      oracleUser=projectHelper.getOracleUser(oracleSid, scheme)
      oraclePasswd=projectHelper.getOraclePasswd(oracleSid, scheme)
      self.unittest(oracleSid,oracleUser,oraclePasswd,ignoreErrors)
      print "unit tests for scheme '"+scheme+"' executed."






import wx
import AbstractPanel as AbstractPanel

class ComboBoxPanel(AbstractPanel.AbstractPanel):

  def getComboBoxControl(self):
    return self.__comboBoxControl
  
  def getValue(self):
    comboBoxControl=self.getComboBoxControl()
    return comboBoxControl.GetValue()
  
  def setValue(self, value):
    comboBoxControl=self.getComboBoxControl()
    comboBoxControl.SetValue(value)
    
  def clear(self):
    comboBoxControl=self.getComboBoxControl()
    comboBoxControl.Clear()
    
  def append(self, choice):
    comboBoxControl=self.getComboBoxControl()
    comboBoxControl.Append(choice)
  
  def appendItems(self, choices):
    comboBoxControl=self.getComboBoxControl()
    comboBoxControl.AppendItems(choices)
  
  def setItems(self, choices):
    comboBoxControl=self.getComboBoxControl()
    comboBoxControl.SetItems(choices)
    

  def __init__(self, parent, id, label, choices):
    AbstractPanel.AbstractPanel.__init__(self, parent, id)
    
    sizer=wx.BoxSizer(wx.HORIZONTAL)  
    self.__staticText = wx.StaticText(self, id, label)  
    self.__staticText.SetMinSize((100,20))      
    self.__comboBoxControl=wx.ComboBox(self, id, choices=choices)
    #width = self.__comboBoxControl.GetSize()[0]
    
    #self.__comboBoxControl.SetMinSize((width,30))
    sizer.Add(self.__staticText,0)  
    sizer.Add(self.__comboBoxControl,1)
    self.SetSizer(sizer)    



#!/usr/bin/env python

import os
import platform
import NooraException as NooraException
import subprocess

BASE_DIR    = os.path.abspath('.')
# 'constant' to determine if we're on the cyswin platform
ON_CYGWIN=platform.system().lower().find("cygwin") == -1;

class ComponentHelper:
  
  def __init__(self):
    pass

  def fileNotPresent(self, url):
    if os.path.isfile(url):
      return False
    return True      


  def folderNotPresent(self, folder):
    if os.path.isdir(folder):
      return False
    return True

  def folderPresent(self, folder):
    if os.path.isdir(folder):
      return True
    return False

  def failOnEmpty(self, values, message):
    if len(values)==0:
      raise NooraException.NooraException(message)

  def failOnFolderNotPresent(self, folder, message):
    if self.folderNotPresent(folder):
      raise NooraException.NooraException(message)

  def failOnFolderPresent(self, folder, message):
    if self.folderPresent(folder):
      raise NooraException.NooraException(message)

  def failOnNone(self, value, message):
    if value==None:
      raise NooraException.NooraException(message)
  
  def failOnFileNotPresent(self, url, message):
    if self.fileNotPresent(url):
      raise NooraException.NooraException(message)
  
  def hasValue(self, list, value):
    for item in list:
      if item==value:
        return True
    return False
  
  def failOnValueNotFound(self, list, value, message):  
    if self.hasValue(list, value)==False:
      raise NooraException.NooraException(message)


  def findFiles(self, folder):
    result=[]
    if os.path.isdir(folder):
      files=os.listdir(folder)
      for file in files:
        url=folder+os.sep+file
        if os.path.isfile(url):
          result.append(file)
      result.sort()
    return result

  def readFile(self, filename):
    handle=open(filename,'rb')
    stream=handle.read()
    handle.close()
    return stream


  # if we're on cygwin: change cygwin path to windows path 
  # so we can use it as a command line param for windows programs (e.g. sqlplus)
  # (exec.. so pretty expensive :-( )
  def cleanPath(self, path):
    if ON_CYGWIN:
      return path
    else:
      proc = subprocess.Popen(["cygpath -wa "+ path], stdout=subprocess.PIPE, shell=True);
      (out, err) = proc.communicate();
      result = out.rstrip();      
      
    return result;




     



import wx
import gui.panels.AbstractPanel as AbstractPanel

class DirectoryPicker(AbstractPanel.AbstractPanel):

    def getDirectory(self):
        return self.__directory
  
    def getValue(self):
        return self.__directory.GetValue();
  
    def setValue(self, value):
        self.__directory.SetValue(value);

    def onBrowse(self, event):
        dlg = wx.DirDialog(self, "Choose a directory:", style=wx.DD_DEFAULT_STYLE | wx.DD_NEW_DIR_BUTTON)
        if dlg.ShowModal() == wx.ID_OK:
            self.setValue(dlg.GetPath())
        dlg.Destroy()

    def __init__(self, parent, id):
        AbstractPanel.AbstractPanel.__init__(self, parent, wx.NewId())
    
        sizer=wx.BoxSizer(wx.HORIZONTAL)        
        self.__directory=wx.TextCtrl(self, id)
        self.__browseButton = wx.Button(self, wx.NewId(), "Browse")  
        sizer.Add(wx.StaticText(self,wx.NewId(),"Choose directory"))
        sizer.Add(self.__directory,1)
        sizer.Add(self.__browseButton,0)
        self.SetSizer(sizer)
      
        wx.EVT_BUTTON(self, self.__browseButton.GetId(), self.onBrowse)  



#!/usr/bin/env python

class ClassLoader:
    
    def __init__(self):
        pass
    
    def find(self, moduleName,className):
        mod = __import__(moduleName ,globals(), locals(), [''])
        
        clazz=getattr(mod,className)
        
        clazzInstance=clazz()
        return clazzInstance
    
    def findByPattern(self,pattern):
        patternList = pattern.split(".")
        listLength=len(patternList)
        className=patternList[listLength-1]
        moduleName=".".join(patternList[0:listLength-1])
        return self.find(moduleName, className)

    
   
        




import core.config.ConfigReader
import core.NooraException as NooraException
import core.StreamHelper as StreamHelper

M_LF = chr(10)

class ConfigReaderProperty(core.config.ConfigReader):
    '''
    The original config (property based) reader
    '''

    def __init__(self, filename):
        core.config.ConfigReader.ConfigReader.__init__(self, filename)

        self.__lines = []
        self.__message = None
        self.__filename = filename
        self.loadFromFile(filename)

    def parse(self, stream):
        stream = StreamHelper.StreamHelper().convert(stream)
        lines = stream.split(chr(10))
        for line in lines:
            self.__lines.append(line)

    def loadFromFile(self, filename):
        try:
            handle = open(filename, 'r')
            stream = handle.read()
            handle.close()
            self.parse(stream)
        except IOError:
            self.setMessage('project configuration file "' + filename + '" not found.')

    def loadFromStream(self, stream):
        self.parse(stream)

    def saveToFile(self, filename):
        stream = M_LF.join(self.__lines)
        handle = open(filename, 'w')
        handle.write(stream)
        handle.close()

    def getValue(self, keyword):
        lines = self.__lines
        for line in lines:
            if line.startswith(keyword):
                values = line.split('=')[1::]
                value = '='.join(values)
                return eval(value)
        return None

    def setValue(self, keyword, value):
        lines = self.__lines
        for line in lines:
            if line.startswith(keyword):
                newLine = keyword + '=' + str(value)
                lines[lines.index(line)] = newLine


    def hasValue(self, keyword, value):
        values = self.getValue(keyword)
        if values != None:
            for val in values:
                if val.lower() == value.lower():
                    return True
        return False

  # deprecated, use failOnValueNotFound instead.
    def invalidValue(self, keyword, values):
        for value in values:
            if self.hasValue(keyword, value) == False:
                raise NooraException.NooraException("the given value " + value + " for keyword " + keyword + " is not valid for this project.")

    def failOnValueNotFound(self, keyword, values, message):
        for value in values:
            if self.hasValue(keyword, value) == False:
                raise NooraException.NooraException(message)

    def failOnValueFound(self, keyword, values, message):
        for value in values:
            if self.hasValue(keyword, value) == True:
                raise NooraException.NooraException(message)

    def failOnConfigNotLoaded(self):
        if self.getMessage() != None:
            print self.getMessage()
            exit(1)


    def setMessage(self, message):
        self.__message = message

    def getMessage(self):
        return self.__message

    def getLines(self):
        return self.__lines

    def getFilename(self):
        return self.__filename




#!/usr/bin/env python

import core.ProjectHelper as ProjectHelper
import core.ConfigReader  as ConfigReader
import os
import sys

__revision__ = "$Revision: $"

class Connector:

  def __init__(self):
    configReader=ConfigReader.ConfigReader('project.conf')
    self.setConfigReader(configReader)
    self.setProjectHelper(ProjectHelper.ProjectHelper(configReader))    
    self.setNooraDir(os.path.abspath(os.path.dirname(sys.argv[0])))

  def setConfigReader(self, configReader):
    self.__configReader=configReader

  def getConfigReader(self):
    return self.__configReader
  
  def setProjectHelper(self, projectHelper):
    self.__projectHelper=projectHelper

  def getProjectHelper(self):
    return self.__projectHelper

  def setNooraDir(self, path):
    self.__nooraDir=path
    
  def getNooraDir(self):
    return self.__nooraDir
  
  def getDatabases(self):
    return []
  
  def execute(self, oracleSid, oracleUser, oraclePasswd, oracleScript, paramA, paramB):
    pass
    



import wx
import Settings as Settings
import MainArtProvider as MainArtProvider

class MainToolBar(wx.ToolBar):

  def __init__(self,parent,id,*args, **kwargs):        
    wx.ToolBar.__init__(self,parent,id,*args, **kwargs)
    mainArtProvider=MainArtProvider.MainArtProvider()
    wx.ArtProvider.Push(mainArtProvider)
    self.AddLabelTool(Settings.ID_NEW_PROJECT, '', MainArtProvider.MainArtProvider.GetBitmap(wx.ART_NEW, wx.ART_TOOLBAR, (16, 16)),wx.NullBitmap,0,'Create a new project','Create a new project')
    self.AddLabelTool(Settings.ID_OPEN_PROJECT, '', MainArtProvider.MainArtProvider.GetBitmap(wx.ART_FILE_OPEN, wx.ART_TOOLBAR, (16, 16)),wx.NullBitmap,0,'Open an existing project','Open an existing project')
    
    self.AddSeparator()
    

    self.AddLabelTool(Settings.ID_EXECUTE,'Execute', wx.ArtProvider.GetBitmap(wx.ART_GO_FORWARD, wx.ART_TOOLBAR, (16, 16)),wx.NullBitmap,0,'Execute command','Execute command')
    self.AddLabelTool(Settings.ID_CLEAR,'', wx.ArtProvider.GetBitmap(wx.ART_UNDO, wx.ART_TOOLBAR, (16, 16)),wx.NullBitmap,0,'Clear console output','Clear console output')


#!/usr/bin/env python

__revision__ = "$Revision: $"

class ParameterDefinition:

  def __init__(self, key, parameters):
    self.__key=key
    self.__parameters=parameters

  def setKey(self, key):
    self.__key=key
    
  def getKey(self):
    return self.__key
  
  def setParameters(self, parameters):
    self.__parameters
    
  def getParameters(self):
    return self.__parameters
  
  def getFirstParameter(self):
    return self.getParameters()[0]
  
  def addParameter(self, key, parameters):
    self.setKey(key)
    self.setParameters(parameters)
    



#!/usr/bin/env python

import core.Plugin as Plugin
import os


class CreatePlugin(Plugin.Plugin):
  def __init__(self):
    Plugin.Plugin.__init__(self)
    self.setType("CREATE")

  def getUsage(self):  
    print "NoOra database installer, create.py"
    print "executes the defined baseline scripts in the create folder"
    print "-s= --sid=     required contains the tnsname of the database."
    print "-u= --scheme=  not required, contains the scheme of "
    print "               the database objects to drop."
    print "-e= --env=     not required, used for mapping "
    print "               the username and password."
    print "-nocompile     not required, disable the compilation of "
    print "               packages, triggers and views."
    

  def getCreateDir(self):
    return self.getBaseDir()+os.sep+'create'

  def recompile(self, oracleSid, oracleUser, oraclePasswd, ignoreErrors):
    connector=self.getConnector()
    oracleScript=self.getScriptDir()+os.sep+'recompile.sql'
    connector.execute(oracleSid, oracleUser, oraclePasswd, oracleScript,'','', ignoreErrors)


  def execute(self, parameterHelper):
    if parameterHelper.hasParameter('-h'):
      self.getUsage()
      exit(1)    

    ignoreErrors=False  
    if  parameterHelper.hasParameter('-ignore_errors')==True:
      ignoreErrors=True      
      

    configReader=self.getConfigReader()
    projectHelper=self.getProjectHelper()

    oracleSid=parameterHelper.getParameterValue(['-s=','--sid='],[])
    projectHelper.failOnEmpty(oracleSid,'no oracle sid was given.')
    configReader.failOnValueNotFound('ORACLE_SIDS',oracleSid,'the given oracle sid is not valid for this project.')
    oracleSid=oracleSid[0]
    
    schemes=configReader.getValue('SCHEMES')
    schemes=parameterHelper.getParameterValue(['-u=','--scheme=','--user='],schemes)
    configReader.failOnValueNotFound('SCHEMES',schemes,'the given scheme is not valid for this project.')

    environment=configReader.getValue('DEFAULT_ENVIRONMENT')
    environment=parameterHelper.getParameterValue(['-e=','--env='],[environment])
    projectHelper.failOnEmpty(environment,'no environment was found')
    configReader.failOnValueNotFound('ENVIRONMENTS',environment,'the given environment is not valid for this project.')
    environment=environment[0]

    connector=self.getConnector()

    for scheme in schemes:
      print "creating scheme '"+scheme+"' in database '"+oracleSid+"' using environment '"+environment+"'"
      oracleUser=projectHelper.getOracleUser(oracleSid, scheme)
      oraclePasswd=projectHelper.getOraclePasswd(oracleSid, scheme)

      url=self.getCreateDir()+os.sep+scheme+os.sep+'install_scheme_'+environment+'.sql'
      projectHelper.failOnFileNotPresent(url,scheme+os.sep+'install_scheme_'+environment+'.sql not found, try to build this scheme.')
      connector.execute(oracleSid, oracleUser, oraclePasswd, url,'','', ignoreErrors)
    
      print "scheme '"+scheme+"' created."

    if  parameterHelper.hasParameter('-nocompile')==False:
      for scheme in schemes:
        print "compiling scheme '"+scheme+"' in database '"+oracleSid+"' using environment '"+environment+"'"
        oracleUser=projectHelper.getOracleUser(oracleSid, scheme)
        oraclePasswd=projectHelper.getOraclePasswd(oracleSid, scheme)
        self.recompile(oracleSid,oracleUser,oraclePasswd, ignoreErrors)
        print "scheme '"+scheme+"' compiled."





import wx
import AbstractPanel as AbstractPanel

class TextPanel(AbstractPanel.AbstractPanel):

  def getTextControl(self):
    return self.__textControl
  
  def getValue(self):
    textControl=self.getTextControl()
    return textControl.GetValue()
  
  def setValue(self, value):
    textControl=self.getTextControl()
    textControl.SetValue(value)

  def __init__(self, parent, id, label):
    AbstractPanel.AbstractPanel.__init__(self, parent, id)
    
    sizer=wx.BoxSizer(wx.HORIZONTAL)  
    self.__staticText = wx.StaticText(self, id, label)  
    
    
         
    self.__textControl=wx.TextCtrl(self, id)
    width,height=self.__textControl.GetSize().Get()   
    self.__textControl.SetMinSize((300,height))
    self.__staticText.SetMinSize((100,height))  
    sizer.Add(self.__staticText,0)  
    sizer.Add(self.__textControl,1)
    self.SetSizer(sizer)
    self.SetAutoLayout(True)    



#!/usr/bin/env python
import core.ApplicationException  as ApplicationException
import os.path

class Fileable:
  def __init__(self, pathName=None):
    pass
    
  @staticmethod
  def pathSeperator(self):
    raise ApplicationException.ApplicationException("method not implemented")
  
  def exists(self):
    raise ApplicationException.ApplicationException("method not implemented")
  
  def notExists(self):
    raise ApplicationException.ApplicationException("method not implemented")
  
  def isFile(self):
    raise ApplicationException.ApplicationException("method not implemented")
  
  def isDirectory(self):
    raise ApplicationException.ApplicationException("method not implemented")
  
  def getName(self):
    raise ApplicationException.ApplicationException("method not implemented")
  
  def getPath(self):
    raise ApplicationException.ApplicationException("method not implemented")
  
  def getExtension(self):
    raise ApplicationException.ApplicationException("method not implemented")
  
  def getRoot(self):
    raise ApplicationException.ApplicationException("method not implemented")
  
  def delete(self,recursive=False):
    raise ApplicationException.ApplicationException("method not implemented")

class File(Fileable):
  def __init__(self, pathName=None):
    self.__pathName=pathName
    
  @staticmethod
  def pathSeperator():
    return os.sep    
    
  def exists(self):
    if self.isFile():
      return True
    if self.isDirectory():
      return True
    return False
      
  def notExists(self):
    if self.exists():
      return False
    return True
  
  def isFile(self):
    pathName = self.__pathName
    return os.path.isfile(pathName)
  
  def isDirectory(self):
    pathName = self.__pathName
    return os.path.isdir(pathName)
  
  def getName(self):
    pathName = self.__pathName
    folder,filename=os.path.split(pathName)
    return filename
  
  def getPath(self):
    pathName = self.__pathName
    folder,filename=os.path.split(pathName)
    return folder

  def getExtension(self):
    pathName = self.__pathName
    root,extension=os.path.splitext(pathName)
    return extension.lstrip('.')  
  
  def getRoot(self):
    pathName = self.__pathName
    root,extension=os.path.splitext(pathName)
    return root 

  def delete(self):
    pathName = self.__pathName
    if self.isFile():      
      os.remove(pathName)
    if self.isDirectory():
      os.rmdir(pathName)



class Readable:
  
  def __init__(self):
    pass
  
  def read(self):  
    raise ApplicationException.ApplicationException("method not implemented")
  
  def close(self):
    raise ApplicationException.ApplicationException("method not implemented")
  
  
class FileReader(Readable):
  def __init__(self, file=None):
    Readable.__init__(self)
    self.__file = file
    pathName = file.getPath() + file.getName()
    self.__handle = open(pathName,'rb')
    
  def read(self):
    handle = self.__handle
    stream = handle.read()
    stream = stream.replace(chr(13)+chr(10),chr(10))
    stream = stream.replace(chr(13),chr(10)) 
    return stream
  
  def getFile(self):
    return self.__file
    
  def close(self):
    handle = self.__handle
    handle.close()
    
    
    
    
class Writeable:
  
  def __init__(self):
    pass
  
  def write(self, buffer):  
    raise ApplicationException.ApplicationException("method not implemented")
  
  def close(self):
    raise ApplicationException.ApplicationException("method not implemented")


class FileWriter(Writeable):
  def __init__(self, file=None):
    Writeable.__init__(self)
    self.__file = file
    pathName = file.getPath() + file.getPathSeperator() + file.getName()        
    self.__handle = open(pathName,'wb')
    
  def write(self, buffer):
    handle = self.__handle
    handle.write(buffer)
    
  def close(self):
    handle = self.__handle
    handle.close()
    
    
class Files:
  def __init__(self):
    pass
  
  def copy(self, fileReader, fileWriter):
    stream = fileReader.read()
    fileReader.close()
    
    fileWriter.write(stream)
    fileWriter.close()
    
  def move(self, fileReader, fileWriter):
    stream = fileReader.read()
    fileReader.close()
    
    fileWriter.write(stream)
    fileWriter.close()
    
    file = fileReader.getFile()
    file.delete()
  
  def list(self, file=None,recursive=False, exclude=None):
    result=[]
    if file.exists():
      folder = file.getPath()
      fileList=os.listdir(folder)

      for fileItem in fileList:
        pathName = folder + os.sep + fileItem
        candidateFile = File(pathName)
        if candidateFile.isFile() and exclude!="file":          
          result.append(candidateFile)
        if candidateFile.isDirectory() and exclude!="directory":
          result.append(candidateFile)
        if candidateFile.isDirectory() and recursive==True:
          recursiveFiles = self.list(file, recursive, exclude)
          for recursiveFile in recursiveFiles:
            result.append(recursiveFile)
      result.sort()
    return result

  
  def delete(self, file=None, recursive=False):
    if file.isFile():
      file.delete()
    if file.isDirectory() and recursive==False:
      file.delete()
    if file.isDirectory() and recursive==True:
      foundFiles=self.listFiles(file, recursive)
      for foundFile in foundFiles:
        foundFile.delete()

      foundDirectories=self.listDirectories(file)
      foundDirectories.reverse()
      for foundDirectory in foundDirectories:
        foundDirectory.delete()

      file.delete()    

class Property:
  
  def __init__(self, key, value):
    self.__key = key
    self.__value = value
    
  def getKey(self):
    return self.__key
  
  def getValue(self):
    return self.__value
  
  def setValue(self, value):
    self.__value = value


class Loadable:  
  def __init__(self):
    pass
  
  def load(self, fileReader = None):  
    raise ApplicationException.ApplicationException("method not implemented")
  
class NoOraPropertyLoader(Loadable):
  def __init__(self, properties):
    Loadable.__init__(self)
    self.__properties = properties

  def getProperties(self):
    return self.__properties
    
    
  def load(self, fileReader = None):
    properties = self.getProperties()
    
    lines = fileReader.read()
    lines = lines.split(chr(10))
    buffer=[]
    for line  in lines:
      if len(line)!=0 and line.startswith("#")==False:
        buffer.append(line)

    property = None
    for line in buffer:
      pairs=line.split("=",1)
      
      if len(pairs)==2:
        key = pairs[0]
        value  = pairs[1].strip()
        property = properties.setProperty(key, value)
      if len(pairs)==1:
        key = property.getKey()
        value = property.getValue() + pairs[0].strip()
        property = properties.setProperty(key, value)
    return properties
  
class Properties:

  def __init__(self):
    self.__properties = []

  def clear(self):
    self.__properties = []
    


  def containsProperty(self, key):
    result = True
    property = self.getProperty(key)
    if property == None:
      result = False
    return result
    

  def setProperty(self, key, value):
    properties = self.__properties
    if self.containsProperty(key):
      property = self.getProperty(key)
      properties.remove(property)          
    property = Property(key, value)
    properties.append(property)
    return property

  def size(self):
    properties=self.__properties
    return len(properties)
  
  def list(self):
    return self.__properties
  
  def getProperty(self, key):
    result = None
    properties = self.__properties
    for property in properties:
      if property.getKey() == key:
        result = property
    return result
       





#!/usr/bin/env python

from setuptools import setup

setup(
    name='noora',
    version='0.0.8.2',
    description='noora database installer.',
    author='Jan Ripke',
    author_email='janripke@gmail.com',
    url='https://sourceforge.net/projects/noora/',
    packages=['noora'],
      long_description="""\
      NoOra is an attempt to apply a pattern to develop and install Oracle database projects, to promote portability and productivity.  ...
      """,
      classifiers=[
          "License :: OSI Approved :: GNU General Public License (GPL)",
          "Programming Language :: Python",
          "Development Status :: 5 - Production/Stable",
          "Intended Audience :: Developers",
          "Topic :: Database",
      ],
      keywords='database install tools',
      license='GPL',
      install_requires=[
        'setuptools',
        'wxpython',
      ],
      )


#!/usr/bin/env python

import core.Plugin as Plugin
import core.StreamHelper  as StreamHelper
import os

M_LF=chr(10)


class BuildPlugin(Plugin.Plugin):
  def __init__(self):
    Plugin.Plugin.__init__(self)
    self.setType("BUILD")

  def getUsage(self):
    print "NoOra database installer, build.py"
    print "creates installation scripts"
    print "-u= --user= --scheme=  not required, contains the scheme."
    print "-v= --verion=  not required, contains the version."

  def hasItem(self, items, value):
    for item in items:
      if item.lower()==value.lower():
        return True
    return False

  def appendNotPresent(self, items, value):
    if self.hasItem(items, value)==False:
      items.append(value)
    return items


  def synchronizeFile(self, folder, filename):

    projectHelper=self.getProjectHelper()  
    files=projectHelper.findFiles(folder)
    url=folder+os.sep+filename

    stream=''          
    if os.path.isfile(url):
      stream=projectHelper.readFile(url)

    # convert the content of the file to linux format (LF)
    streamHelper=StreamHelper.StreamHelper()
    stream=streamHelper.convert(stream)

    lines=stream.split(M_LF)
    for file in files:
      if self.hasItem(lines,'@@'+file)==False:
        print "adding "+folder.split(self.getBaseDir())[1]+os.sep+file
      lines=self.appendNotPresent(lines,'prompt '+folder.split(self.getBaseDir())[1]+os.sep+file)
      lines=self.appendNotPresent(lines,'@@'+file)

    synchronized_lines=list(lines)
    for line in lines:

      if line.startswith('prompt '):
        if self.hasItem(files,line.replace('prompt '+folder.split(self.getBaseDir())[1]+os.sep,''))==False:
          synchronized_lines.remove(line)
      if line.startswith('@@'):        
        if self.hasItem(files,line.replace('@@',''))==False:
          print "removing "+folder.split(self.getBaseDir())[1]+os.sep+line
          synchronized_lines.remove(line)
              
    stream = M_LF.join(synchronized_lines)              
    projectHelper.writeFile(url,stream)    


  def execute(self, parameterHelper):
    if parameterHelper.hasParameter('-h'):
      self.getUsage()
      exit(1)

    projectHelper=self.getProjectHelper()
    configReader=self.getConfigReader()
           
    schemes=configReader.getValue('SCHEMES')
    schemes=parameterHelper.getParameterValue(['-u=','--scheme=','--user='],schemes)
    configReader.invalidValue('SCHEMES',schemes)

    versions=configReader.getValue('VERSIONS')
    versions=parameterHelper.getParameterValue(['-v=','--version='],versions)
    configReader.invalidValue('VERSIONS',versions)

    objects = configReader.getValue('CREATE_OBJECTS')
    environments= configReader.getValue('ENVIRONMENTS')

    for version in versions:
      buildFolder=projectHelper.getBuildFolder(versions, version)
      projectHelper.invalidBuildFolder(buildFolder)

      
      for scheme in schemes:
        globalDdlObjects=[]
        specificDdlObjects=[]
        globalDatObjects=[]
        specificDatObjects=[]

        print "building scheme '"+scheme+"' for version '"+version+"'"
        for object in objects:  

          # global ddl objects
          folder=buildFolder+os.sep+scheme+os.sep+'ddl'+os.sep+object
          if projectHelper.folderPresent(folder):
            self.synchronizeFile(folder,'install.sql')           
            globalDdlObjects.append('@@ddl/'+object+'/install.sql')

          # environment specific ddl objects
          for environment in environments:          
            folder=buildFolder+os.sep+scheme+os.sep+'ddl'+os.sep+object+os.sep+environment
            if projectHelper.folderPresent(folder):
              self.synchronizeFile(folder,'install.sql')
              specificDdlObjects.append([environment,'@@ddl/'+object+'/'+environment+'/install.sql'])          

        # global dat objects
        folder=buildFolder+os.sep+scheme+os.sep+'dat'
        if projectHelper.folderPresent(folder):
          self.synchronizeFile(folder,'install.sql')
          globalDatObjects.append('@@dat/install.sql')

        # environment specific dat objects
        for environment in environments:
          folder=buildFolder+os.sep+scheme+os.sep+'dat'+os.sep+environment
          if projectHelper.folderPresent(folder):
            self.synchronizeFile(folder,'install.sql')
            specificDatObjects.append([environment,'@@dat/'+environment+'/install.sql'])

        # create install_scheme.sql script if not present
        for environment in environments:
          filename='install_scheme_'+environment+'.sql'      
          url=buildFolder+os.sep+scheme+os.sep+filename

          if os.path.isfile(url)==False:
            templateUrl=projectHelper.findTemplateFile('install_scheme.sql')
            projectHelper.copyFile(templateUrl,url)
            stream=projectHelper.readFile(url)            
            stream=stream.replace('<install>','install_'+environment)
            projectHelper.writeFile(url,stream)
      
        # create install.sql for install_scheme.sql
        for environment in environments:
          filename='install_'+environment+'.sql'            
          url=buildFolder+os.sep+scheme+os.sep+filename
                  
          stream = M_LF.join(globalDdlObjects)  
          for specificDdlObject in specificDdlObjects:
            if specificDdlObject[0]==environment:
              stream = stream + M_LF + specificDdlObject[1]
          stream = stream + M_LF + M_LF.join(globalDatObjects)  
          for specificDatObject in specificDatObjects:
            if specificDatObject[0]==environment:
              stream = stream + M_LF + specificDatObject[1]

          projectHelper.writeFile(url,stream)      





#!/usr/bin/env python
import wx

import gui.MainFrame as MainFrame

modules = {'TopFrame': [1, 'Main frame of the Application', u'gui/TopFrame.py']}

class NooraGuiApp(wx.App):
  def __init__(self, redirect=False, filename=None):
    wx.App.__init__(self, redirect, filename)

  def OnInit(self):
    appTitle='NoOra'
    self.main = MainFrame.MainFrame(self,appTitle)
    self.main.SetSize((600,500))
    self.main.CenterOnScreen()
    self.SetTopWindow(self.main)
    self.main.Show(True)    
    return True

def main():
    application = NooraGuiApp()
    application.MainLoop()

if __name__ == '__main__':
    main()



#!/usr/bin/env python

class Version:

  def __init__(self, major=None, minor=None, revision=None, patch=None):
    self.__major = major
    self.__minor = minor
    self.__revision = revision
    self.__patch = patch

  def getMajor(self):
    return self.__major
  
  def getMinor(self):
    return self.__minor
  
  def getRevision(self):
    return self.__revision
  
  def getPatch(self):    
    return self.__patch
  
  def list(self):
    result = []    
    if self.__major!=None:
      result.append(self.__major)
    if self.__minor!=None:
      result.append(self.__minor)
    if self.__revision!=None:
      result.append(self.__revision)
    if self.__patch!=None:
      result.append(self.__patch)
    return result
  
  def __eq__(self, other):
    if self.list() == other.list():  # compare name value (should be unique)
      return 1
    else: return 0     
  

  





#!/usr/bin/env python

from org.noora.app.Appable import Appable
from org.noora.io.File import File
import logging
import os


class NoOraApp(Appable):
  
  logger = logging.getLogger("NoOraLogger")
  
  __revision__ = "$Revision: 229 $"
  __version__  = "0.0.8.2"

  
  def __init__(self):
    Appable.__init__(self)

  def getRevision(self):  
    print "noora version " + self.__version__  + "_" + self.__revision__.split(":")[1].rstrip("$").strip()


  def getConfigFile(self, properties):
    currentDir = properties.getPropertyValue("current.dir")
    file = File(currentDir + os.sep + "project.conf")
    if file.exists():
      return file
    
    nooraDir = properties.getPropertyValue("noora.dir")
    file = File(nooraDir + os.sep + "project.conf")
    return file


    



#!/usr/bin/env python

from org.noora.plugin.Plugin import Plugin
from org.noora.helper.PropertyHelper import PropertyHelper
from org.noora.io.File import File
from org.noora.cl.OptionFactory import OptionFactory
from org.noora.plugin.ConnectionExecutor import ConnectionExecutor
from org.noora.connector.ExecuteFactory import ExecuteFactory
from org.noora.connector.ConnectorFactory import ConnectorFactory
from org.noora.plugin.mysql.drop.BlockedHostException import BlockedHostException
import os

class DropPlugin(Plugin):
  
  __revision__ = "$Revision: 272 $"
  
  def __init__(self):    
    Plugin.__init__(self, "DROP", ConnectorFactory.newMysqlConnector())
    
    #self.addParameterDefinition('database',['-s','-si','--sid'])
    #self.addParameterDefinition('scheme',['-u','-sc','--scheme'])

  def getDescription(self):
    return "drops database objects in mysql-servers."


  def getOptions(self, properties):
    options = Plugin.getOptions(self)
    
    options.addOption("-?", "--help", False, False,  "display help")      
    
    option = OptionFactory.newOption("-h", "--host", True, True, "hostname of the mysql-server.")
    option.setValues(properties.getPropertyValues('MYSQL_HOSTS'))
    options.add(option)
    
    option = OptionFactory.newOption("-d", "--database", True, False, "database in the mysql-server.")
    option.setValues(properties.getPropertyValues('DATABASES'))
    options.add(option)
    
    option = OptionFactory.newOption("-e", "--environment", True, False, "environment descriptor of the mysql-server.")
    option.setValues(properties.getPropertyValues('ENVIRONMENTS'))
    options.add(option)
    
#    options.addOption("--no-compile", True, False, "disable the compilation of database objects.")
    options.addOption("-i", "--ignore-errors", True, False, "ignore errors.")
    return options


  def getDropDir(self, properties):
    #print "noora.dir", os.path.abspath(os.path.dirname(sys.argv[0]))
    return properties.getPropertyValue('noora.dir')+os.sep+'org'+os.sep+'noora'+os.sep+'plugin'+os.sep+'mysql'+os.sep+'drop'
    #return self.getNooraDir()+os.sep+'plugins'+os.sep+'static'+os.sep+'drop'

  def checkBlockedHosts(self, host, properties):
    blockedHosts = properties.getPropertyValues('BLOCKED_HOSTS')
    if host in blockedHosts:
      raise BlockedHostException("blocked host", host)

  def execute(self, commandLine, properties):
    #if parameterHelper.hasParameter('-h'):
    #  self.getUsage()
    #  exit(1)

    ignoreErrors = commandLine.getOptionValue('--ignore-errors', False)

    host = commandLine.getOptionValue('-h')  
    self.checkBlockedHosts(host, properties)

    defaultDatabases = properties.getPropertyValues('DATABASES')
    databases = commandLine.getOptionValues('-d', defaultDatabases)

    defaultEnvironment = properties.getProperty('DEFAULT_ENVIRONMENT')
    environment = commandLine.getOptionValue('-e', defaultEnvironment)

    objects = properties.getPropertyValues('DROP_OBJECTS')


    for database in databases:
      print "dropping database '"+database+"' on host '"+host+"' using environment '"+environment+"'"
      
      users= properties.getPropertyValues('MYSQL_USERS')
      user = PropertyHelper.getUser(users, host, database)
      passwd = PropertyHelper.getPasswd(users, host, database)
      
      connector = self.getConnector()
           
      executor = ExecuteFactory.newMysqlExecute()
      executor.setHost(host)
      executor.setDatabase(database)
      executor.setIgnoreErrors(ignoreErrors)
      executor.setPassword(passwd)
      executor.setUsername(user)      

      for object in objects:      
        folder=File(self.getDropDir(properties)+os.sep+object)
        
        ConnectionExecutor.execute(connector, executor, properties, folder)
      
      print "database '"+database+"' dropped."    






#!/usr/bin/env python
from org.noora.plugin.PluginException import PluginException
__revision__ = "$Revision: $"

class Pluginable:

  def __init__(self, type, connectable):
    pass
  
  def execute(self, parameters, properties):
    raise PluginException("method not implemented") 
    
  def setConnector(self, connector):
    raise PluginException("method not implemented")

  def getConnector(self):
    raise PluginException("method not implemented")

  def setExecutor(self, executor):
    raise PluginException("method not implemented")

  def getExecutor(self):
    raise PluginException("method not implemented")


  def getUsage(self):
    raise PluginException("method not implemented")
  
  def getDescription(self):
    raise PluginException("method not implemented")

  def setType(self, type):
    raise PluginException("method not implemented")

  def getType(self):
    raise PluginException("method not implemented")

  def getRevision(self):
    raise PluginException("method not implemented")



#!/usr/bin/env python

import core.Plugin as Plugin
import os
import subprocess


class RecreatePlugin(Plugin.Plugin):
  def __init__(self):
    Plugin.Plugin.__init__(self)
    self.setType("RECREATE")


  def getUsage(self):  
    print "NoOra database installer, recreate.py"
    print "recreates the database objects of the defined schemes."
    print "-s= --sid=     required contains the tnsname of the database."
    print "-u= --scheme=  not required, contains the scheme of "
    print "               the database objects to drop."
    print "-e= --env=     not required, used for mapping "
    print "               the username and password."
    print "-nocompile     not required, disable the compilation of "
    print "               packages, triggers and views."  
    print "-m= --max=     not required, after the given version recreation will stop."
    print "-test          not required, executes the defined unit tests after recreation."


  def getMaxVersion(self,versions):
    return versions[len(versions)-1]

  def dropDatabase(self, oracleSid, scheme, environment):
    if len(scheme)==0:
      result=subprocess.call(['python',self.getNooraDir()+os.sep+'noora.py','drop','--sid='+oracleSid,'--env='+environment],shell=False)
      if result!=0:
        exit(1)    
    else:
      result=subprocess.call(['python',self.getNooraDir()+os.sep+'noora.py','drop','--sid='+oracleSid,'--scheme='+scheme[0],'--env='+environment],shell=False)
      if result!=0:
        exit(1)

  def createDatabase(self, oracleSid, scheme, environment):
    if len(scheme)==0:
      result=subprocess.call(['python',self.getNooraDir()+os.sep+'noora.py', 'create','--sid='+oracleSid,'--env='+environment,'-nocompile'])
      if result!=0:
        exit(1)
    else:      
      result=subprocess.call(['python',self.getNooraDir()+os.sep+'noora.py','create', '--sid='+oracleSid,'--scheme='+scheme[0],'--env='+environment,'-nocompile'])
      if result!=0:
        exit(1)


  def updateDatabase(self, oracleSid, scheme, environment, versions, maxVersion):
    for version in versions:
      if version!=versions[0]:
        if len(scheme)==0:
          result=subprocess.call(['python',self.getNooraDir()+os.sep+'noora.py','update','-v='+version,'--sid='+oracleSid,'--env='+environment,'-nocompile'])        
          if result!=0:
            exit(1)
        else:
          result=subprocess.call(['python',self.getNooraDir()+os.sep+'noora.py','update','-v='+version,'--sid='+oracleSid,'--scheme='+scheme,'--env='+environment,'-nocompile'])
          if result!=0:
            exit(1)
        if version==maxVersion:
          break


  def recompile(self, oracleSid, oracleUser, oraclePasswd,ignoreErrors):
    connector=self.getConnector()
    oracleScript=self.getScriptDir()+os.sep+'recompile.sql'
    connector.execute(oracleSid, oracleUser, oraclePasswd, oracleScript,'','',ignoreErrors)


  def unittest(self, oracleSid, oracleUser, oraclePasswd,ignoreErrors):
    connector=self.getConnector()
    oracleScript=self.getScriptDir()+os.sep+'unittest.sql'
    connector.execute(oracleSid, oracleUser, oraclePasswd, oracleScript,'','',ignoreErrors)


  def execute(self, parameterHelper):
    if parameterHelper.hasParameter('-h'):
      self.getUsage()
      exit(1)    

    ignoreErrors=False  
    if  parameterHelper.hasParameter('-ignore_errors')==True:
      ignoreErrors=True      


    configReader=self.getConfigReader()
    projectHelper=self.getProjectHelper()

    oracleSid=parameterHelper.getParameterValue(['-s=','--sid='],[])
    projectHelper.failOnEmpty(oracleSid,'no oracle sid was given.')
    configReader.failOnValueNotFound('ORACLE_SIDS',oracleSid,'the given oracle sid is not valid for this project.')
    oracleSid=oracleSid[0]

    scheme=parameterHelper.getParameterValue(['-u=','--scheme=','--user='],[])
    
    schemes=configReader.getValue('SCHEMES')
    schemes=parameterHelper.getParameterValue(['-u=','--scheme=','--user='],schemes)
    configReader.failOnValueNotFound('SCHEMES',schemes,'the given scheme is not valid for this project.')

    environment=configReader.getValue('DEFAULT_ENVIRONMENT')
    environment=parameterHelper.getParameterValue(['-e=','--env='],[environment])
    projectHelper.failOnEmpty(environment,'no environment was found')
    configReader.failOnValueNotFound('ENVIRONMENTS',environment,'the given environment is not valid for this project.')
    environment=environment[0]

    versions=configReader.getValue('VERSIONS')
    projectHelper.failOnEmpty(versions,'the variable VERSIONS is not set.')
    maxVersion=self.getMaxVersion(versions)
    maxVersion=parameterHelper.getParameterValue(['-m=','--max='],[maxVersion])
    configReader.failOnValueNotFound('VERSIONS',maxVersion,'the given max version is not valid for this project.')
    maxVersion=maxVersion[0]

    self.dropDatabase(oracleSid, scheme, environment)
    self.createDatabase(oracleSid, scheme, environment)
    self.updateDatabase(oracleSid, scheme, environment, versions, maxVersion)

    if  parameterHelper.hasParameter('-nocompile')==False:
      for scheme in schemes:
        print "compiling scheme '"+scheme+"' in database '"+oracleSid+"' using environment '"+environment+"'"
        oracleUser=projectHelper.getOracleUser(oracleSid, scheme)
        oraclePasswd=projectHelper.getOraclePasswd(oracleSid, scheme)
        self.recompile(oracleSid,oracleUser,oraclePasswd,ignoreErrors)
        print "scheme '"+scheme+"' compiled."

    if parameterHelper.hasParameter('-test')==True:
      for scheme in schemes:
        oracleUser=projectHelper.getOracleUser(oracleSid, scheme)
        oraclePasswd=projectHelper.getOraclePasswd(oracleSid, scheme)
        self.unittest(oracleSid, oracleUser, oraclePasswd,ignoreErrors)





#!/usr/bin/env python

import core.Plugin as Plugin
import os


class CleanPlugin(Plugin.Plugin):
  def __init__(self):
    Plugin.Plugin.__init__(self)
    self.setType("CLEAN")


  def getUsage(self):
    print "NoOra database installer, clean"
    print "removes installation scripts"
    print "-u= --scheme=  not required, contains the scheme."
    print "-v= --verion=  not required, contains the version."

  def execute(self, parameterHelper):
    if parameterHelper.hasParameter('-h'):
      self.getUsage()
      exit(1)    

    configReader=self.getConfigReader()
    projectHelper=self.getProjectHelper()
    schemes=configReader.getValue('SCHEMES')
    schemes=parameterHelper.getParameterValue(['-u=','--scheme=','--user='],schemes)
    configReader.invalidValue('SCHEMES',schemes)

    versions=configReader.getValue('VERSIONS')
    versions=parameterHelper.getParameterValue(['-v=','--version='],versions)
    configReader.invalidValue('VERSIONS',versions)

    objects = configReader.getValue('CREATE_OBJECTS')
    environments= configReader.getValue('ENVIRONMENTS')

    for version in versions:
      buildFolder=projectHelper.getBuildFolder(versions, version)
      projectHelper.invalidBuildFolder(buildFolder)

      for scheme in schemes:

        print "cleaning scheme '"+scheme+"' for version '"+version+"'"
        for object in objects:  
          for environment in environments:          

            # environment specific ddl objects
            folder=buildFolder+os.sep+scheme+os.sep+'ddl'+os.sep+object+os.sep+environment
            url=folder+os.sep+'install.sql'
            if os.path.isfile(url):
              os.remove(url)

          # global ddl objects
          folder=buildFolder+os.sep+scheme+os.sep+'ddl'+os.sep+object
          url=folder+os.sep+'install.sql'
          if os.path.isfile(url):
            os.remove(url)

        for environment in environments:
 
          # environment specific dat objects
          folder=buildFolder+os.sep+scheme+os.sep+'dat'+os.sep+environment
          url=folder+os.sep+'install.sql'
          if os.path.isfile(url):
            os.remove(url)


        # global dat objects
        folder=buildFolder+os.sep+scheme+os.sep+'dat'
        url=folder+os.sep+'install.sql'
        if os.path.isfile(url):
          os.remove(url)


      # remove install_scheme.sql script
      folder=buildFolder+os.sep+scheme
      for environment in environments:
        url=folder+os.sep+'install_scheme_'+environment+'.sql'
        if os.path.isfile(url):
          os.remove(url)

      # remove install.sql script in the schema folder.
      folder=buildFolder+os.sep+scheme
      for environment in environments:
        url=folder+os.sep+'install_'+environment+'.sql'
        if os.path.isfile(url):
          os.remove(url)





#!/usr/bin/env python

import core.Plugin as Plugin
import os

class DropPlugin(Plugin.Plugin):
  def __init__(self):
    Plugin.Plugin.__init__(self)
    self.setType("DROP")

    self.addParameterDefinition('database',['-s','-si','--sid'])
    self.addParameterDefinition('scheme',['-u','-sc','--scheme'])

  def getDescription(self):
    return "drops the database objects of the defined schemes."

  def getUsage(self):
    print "NoOra database installer, drop.py"
    print self.getDescription()
    print "-s=  --sid=     required contains the tnsname of the database."
    print "-u=  --scheme=  not required, contains the scheme of "
    print "                the database objects to drop."


  def getDropDir(self):
    return self.getNooraDir()+os.sep+'plugins'+os.sep+'static'+os.sep+'drop'

  def execute(self, parameterHelper):
    if parameterHelper.hasParameter('-h'):
      self.getUsage()
      exit(1)

    ignoreErrors=False
    if  parameterHelper.hasParameter('-ignore_errors')==True:
      ignoreErrors=True

    configReader=self.getConfigReader()
    projectHelper=self.getProjectHelper()

    oracleSid=parameterHelper.getParameterValue(['-s=','--sid='],[])
    projectHelper.failOnEmpty(oracleSid,'no oracle sid was given.')
    configReader.failOnValueNotFound('ORACLE_SIDS',oracleSid,'the given oracle sid is not valid for this project.')
    configReader.failOnValueFound('BLOCKED_ORACLE_SIDS',oracleSid,'dropping is blocked for the given oracle_sid.')
    oracleSid=oracleSid[0]

    schemes=configReader.getValue('SCHEMES')
    projectHelper.failOnNone(schemes,'the variable SCHEMES is not set.')
    schemes=parameterHelper.getParameterValue(['-u=','--scheme=','--user='],schemes)
    configReader.failOnValueNotFound('SCHEMES',schemes,'the given scheme is not valid for this project.')

    oracleUsers=configReader.getValue('ORACLE_USERS')
    projectHelper.failOnNone(oracleUsers,'the variable ORACLE_USERS is not set.')
    objects = configReader.getValue('DROP_OBJECTS')
    projectHelper.failOnNone(objects,'the variable DROP_OBJECTS is not set.')

    connector=self.getConnector()

    for scheme in schemes:
      print "dropping scheme '"+scheme+"' in database '"+oracleSid+"'"
      oracleUser=projectHelper.getOracleUser(oracleSid, scheme)
      oraclePasswd=projectHelper.getOraclePasswd(oracleSid, scheme)
      for object in objects:

        # ddl objects
        folder=self.getDropDir()+os.sep+object
        files=projectHelper.findFiles(folder)
        for file in files:
          url=folder+os.sep+file
          print scheme+':'+url.split(self.getNooraDir())[1]
          connector.execute(oracleSid, oracleUser, oraclePasswd, url,'','', ignoreErrors)

      print "scheme '"+scheme+"' dropped."





#!/usr/bin/env python

class Option:
  
  def __init__(self, type=None, longType=None, hasArguments=False, required=False, description=None):
    self.__type = type
    self.__longType = longType
    self.__hasArguments = hasArguments
    self.__description = description
    self.__values = []
    self.__required = required

  def getType(self):
    return self.__type
  
  def setType(self, type):
    self.__type = type

  def setLongType(self):
    self.__longType = type
    
  def getLongType(self):
    return self.__longType

  def hasArguments(self):
    return self.__hasArguments
  
  def hasLongType(self):
    if self.__longType:
      return True
    return False  
  
  def hasValues(self):
    values = self.getValues()
    if values:
      return True
    return False
  
  def getDescription(self):
    return self.__description
  
  def setDescription(self, description):
    self.__description=description
    
  def setValues(self, values):
    self.__values = values
    
  def getValues(self):
    return self.__values
  
  def getValue(self):
    values = self.getValues()
    return values[0]
  
  def setRequired(self, required):
    self.__required = required
    
  def isRequired(self):
    return self.__required
    




#!/usr/bin/env python
from org.noora.cl.OptionFactory import OptionFactory


class Options:
  
  def __init__(self):
    self.__options=[]
       
  def clear(self):
    self.__options=[]
      
  def getOptions(self):
    return self.__options
  
  def add(self, option):
    self.__options.append(option)
  
  def addOption(self, type=None, longType=None, hasArguments=False, required=False, description=None):
    option = OptionFactory.newOption(type, longType, hasArguments, required, description)
    self.__options.append(option)
    return option
    
  def hasOption(self, type):
    options = self.getOptions()
    for option in options:
      if option.getType()==type or option.getLongType()==type:
        return True
    return False      
    
  def getOption(self, type):
    options=self.getOptions()
    for option in options:
      if option.getType()==type or option.getLongType()==type:
        return option
  
  def getRequiredOptions(self):
    result = []
    options=self.getOptions()
    for option in options:
      if option.isRequired():
        result.append(option)
    return result
  
  def getRequiredArguments(self):
    result = []
    options = self.getOptions()
    for option in options:
      if option.hasValues()==False:
        result.append(option)
    return result
  
  def size(self):
    options = self.__options
    return len(options)
  





#!/usr/bin/env python

import os
from org.noora.io.Files import Files
from org.noora.io.File import File
from org.noora.io.Filters import Filters
from org.noora.io.FileFolderFilter import FileFolderFilter
from org.noora.io.FileExtensionFilter import FileExtensionFilter
from org.noora.io.FileFilter import FileFilter

class ConnectionExecutor:
  def __init__(self):
    pass
  
  @staticmethod
  def execute(connector, executor, properties, folder):
    filters = Filters()
        
    excludedFolders=properties.getPropertyValues('EXCLUDED_FOLDERS')            
    for excludedFolder in excludedFolders:
      ef = File(excludedFolder)
      ff = FileFolderFilter(ef)
      filters.add(ff)
          
    excludedExtensions=properties.getPropertyValues('EXCLUDED_EXTENSIONS')
    for excludedExtension in excludedExtensions:
      ef = File("*."+ excludedExtension)
      ff = FileExtensionFilter(ef)
      filters.add(ff)

    excludedFiles=properties.getPropertyValues('EXCLUDED_FILES')
    for excludedFile in excludedFiles:
      ef = File(excludedFile)
      ff = FileFilter(ef)
      filters.add(ff)  
    
    if folder.isDirectory():
      files = Files.list(folder)     
      for file in files:              
        if filters.accept(file)==False and file.isDirectory()==False:  
          url = file.getPath()+os.sep+file.getName()        
          print url
        
#          executor = ExecuteFactory.newMysqlExecute()
#          executor.setHost(host)
#          executor.setDatabase(database)
#          executor.setIgnoreErrors(ignoreErrors)
#          executor.setUsername(user)
#          executor.setPassword(passwd)
          executor.setScript(file)
        
          connector.execute(executor, properties)



import wx
import panels.CancelFinishPanel     as CancelFinishPanel
import panels.HeaderPanel           as HeaderPanel
import gui.Settings                 as Settings
import core.ConfigReader            as ConfigReader


class EditProjectDialog(wx.Dialog):

    def getProjectControl(self):
      return self.__projectControl
    
    def getProject(self):
      projectControl=self.getProjectControl()
      return projectControl.getValue()
        
    def __init__(self, parent, id, title, url):
        
      wx.Dialog.__init__(self, parent, id, title, style=wx.DEFAULT_DIALOG_STYLE|wx.THICK_FRAME|wx.RESIZE_BORDER|wx.TAB_TRAVERSAL)

      sizer = wx.BoxSizer(wx.VERTICAL)
      self.__headerPanel = HeaderPanel.HeaderPanel(self, -1,"NoOra project.conf","View the NoOra project configuration file, project.conf")      
      self.__projectControl=wx.ListCtrl(self, -1, style=wx.LC_REPORT|wx.LC_VRULES|wx.LC_HRULES)
      self.__projectControl.InsertColumn(0, 'Keyword')
      self.__projectControl.InsertColumn(1, 'Value')
      self.__closeButton = wx.Button(self, Settings.ID_CLOSE, "Close")
            
      sizer.Add(self.__headerPanel,0,wx.EXPAND)   
      sizer.Add(self.__projectControl,1,wx.EXPAND|wx.ALL,5)
      sizer.Add(self.__closeButton,0,wx.ALIGN_RIGHT|wx.ALL,5)
              
      self.SetSizer(sizer)
      self.SetMinSize((500,600))
      
      self.Bind(wx.EVT_BUTTON, self.onClose, id=Settings.ID_CLOSE)
      
      configReader=ConfigReader.ConfigReader(url)
      lines=configReader.getLines()
      for line in lines:
        
        if (line.startswith("#")!=True) and (len(line.strip(" "))!=0):
          
          keyword=line.split('=')[0]
          values=line.split('=')[1::]
          value='='.join(values)

          itemCount=self.__projectControl.GetItemCount()
          self.__projectControl.InsertStringItem(itemCount, keyword)
          self.__projectControl.SetStringItem(itemCount, 1, value)
        
          
      self.__projectControl.SetColumnWidth(0, wx.LIST_AUTOSIZE_USEHEADER)  
          

    def onClose(self, evt):
      self.EndModal(Settings.ID_CLOSE)
      
  

  


#!/usr/bin/env python
from org.noora.io.IOException import IOException

class Fileable:
  def __init__(self, pathName=None):
    pass
    
  @staticmethod
  def pathSeperator(self):
    raise IOException("method not implemented")
  
  def exists(self):
    raise IOException("method not implemented")
  
  def notExists(self):
    raise IOException("method not implemented")
  
  def isFile(self):
    raise IOException("method not implemented")
  
  def isDirectory(self):
    raise IOException("method not implemented")
  
  def getName(self):
    raise IOException("method not implemented")
  
  def getPath(self):
    raise IOException("method not implemented")
  
  def getExtension(self):
    raise IOException("method not implemented")
  
  def getRoot(self):
    raise IOException("method not implemented")
  
  def delete(self,recursive=False):
    raise IOException("method not implemented")


       





#!/usr/bin/env python

import core.Plugin as Plugin
import core.VersionHelper as VersionHelper
import os


class PreparePlugin(Plugin.Plugin):
  def __init__(self):
    Plugin.Plugin.__init__(self)
    self.setType("PREPARE")


  def getUsage(self):  
    print "NoOra database installer, prepare.py"
    print "creates the folder structure for the given version"
    print "remarks : the given version must be present in config.VERSIONS"
    print "          the first version in config.VERSIONS is considered as the baseline (create)."
    print "          the folder structure is only created when the version folder is not already present."
    print "-v= --version= required, contains the version to create."
    print "-u= --scheme= --user=  not required, contains the scheme to create. "


  def getSqlVersionStatement(self, versions, version):
    configReader=self.getConfigReader()
    createVersion=versions[0]
    if createVersion==version:
      stream=configReader.getValue('VERSION_INSERT_STATEMENT')
    else:
      stream=configReader.getValue('VERSION_UPDATE_STATEMENT')
      stream=stream.replace('<version>',version)
    return stream

  
  def getSqlEnvironmentStatement(self, environment):
    configReader=self.getConfigReader()
    stream=configReader.getValue('ENVIRONMENT_INSERT_STATEMENT')
    stream=stream.replace('<environment>',environment)
    return stream


  def execute(self, parameterHelper):
    if parameterHelper.hasParameter('-h'):
      self.getUsage()
      exit(1)    

    configReader=self.getConfigReader()
    projectHelper=self.getProjectHelper()
    
    schemes=configReader.getValue('SCHEMES')
    schemes=parameterHelper.getParameterValue(['-u=','--scheme=','--user='],schemes)
    configReader.failOnValueNotFound('SCHEMES',schemes,'the given scheme is not valid for this project.')

    versionScheme=configReader.getValue('VERSION_SCHEME')
    projectHelper.failOnEmpty(versionScheme,'the variable VERSION_SCHEME is not configured for this project.')

    versionInsertStatement=configReader.getValue('VERSION_INSERT_STATEMENT')
    projectHelper.failOnEmpty(versionInsertStatement,'the variable VERSION_INSERT_STATEMENT is not configured for this project.')

    versionUpdateStatement=configReader.getValue('VERSION_UPDATE_STATEMENT')
    projectHelper.failOnEmpty(versionUpdateStatement,'the variable VERSION_UPDATE_STATEMENT is not configured for this project.')

    environments=configReader.getValue('ENVIRONMENTS')
    projectHelper.failOnEmpty(environments,'the variable ENVIRONMENTS is not configured for this project.')

    defaultVersion=configReader.getValue('DEFAULT_VERSION')
    projectHelper.failOnEmpty(defaultVersion,'the variable DEFAULT_VERSION is not configured for this project.')
    version=parameterHelper.getParameterValue(['-v=','--version='],[])

    versions=configReader.getValue('VERSIONS')
    versionHelper=VersionHelper.VersionHelper(versions)

    if len(version)==0:
      version.append(versionHelper.getNextRevision(defaultVersion))

    if len(versions)==0:
      versions=version
    else:
      versions.append(version[0])
    
    version=version[0]
    versionFolder=projectHelper.getBuildFolder(versions, version)
    projectHelper.failOnFolderPresent(versionFolder,'the given version is already present')

    objects=configReader.getValue('CREATE_OBJECTS')
    projectHelper.failOnNone(objects,'the variable CREATE_OBJECTS is not configured for this project.')


    # create the version folder
    os.makedirs(versionFolder)
  
    for scheme in schemes:

      # create the scheme folder
      schemeFolder=versionFolder+os.sep+scheme
      os.mkdir(schemeFolder)

      # create the dat folder
      datFolder=schemeFolder+os.sep+'dat'
      os.mkdir(datFolder)

      # create the version script in the dat folder
      if scheme==versionScheme:
        sqlScript=self.getSqlVersionStatement(versions, version)
        projectHelper.writeFile(datFolder+os.sep+'version.sql', sqlScript)

    # create the environment folders in the dat folder
    for environment in environments:
      os.mkdir(datFolder+os.sep+environment)

      # create the environment script in the dat folder.
      if scheme==versionScheme and versions[0]==version:
        sqlScript=self.getSqlEnvironmentStatement(environment)
        projectHelper.writeFile(datFolder+os.sep+environment+os.sep+'environment.sql', sqlScript)

    # create the ddl folder
    ddlFolder=schemeFolder+os.sep+'ddl'
    os.mkdir(ddlFolder)

    # create the object folders in the ddl folder
    for object in objects:
      os.mkdir(ddlFolder+os.sep+object)

    # update or create the VERSION variable
    configReader.setValue('VERSIONS', versions)
    url=self.getBaseDir()+os.sep+'project.conf'
    configReader.saveToFile(url)

    print "version "+version+" created."





#!/usr/bin/env python

import core.Connector as Connector
import logging


from org.noora.io.File import File
from org.noora.io.FileReader import FileReader
from org.noora.io.Properties import Properties
from org.noora.parser.Parser import Parser
from org.noora.parser.PreProcessor import PreProcessor
from org.noora.io.FileWriter import FileWriter
from org.noora.processor.StartupInfoFactory import StartupInfoFactory
from org.noora.processor.Processor import Processor
from org.noora.processor.Call import Call


class MysqlConnector(Connector.Connector):
  
  def __init__(self):
    Connector.Connector.__init__(self)
  
  def execute(self, mysqlHost, mysqlDatabase, mysqlUser, mysqlPasswd, mysqlScript, paramA, paramB, ignoreErrors):
    #try:
      
      script = File(mysqlScript)
      scriptReader = FileReader(script) 
      
      properties = Properties()
      properties.setProperty('database', mysqlDatabase)     
      parser = Parser(scriptReader,properties)      
      preProcessor = PreProcessor()
      stream = preProcessor.parse(parser)
      
      tmp = File("tmp.sql")
      tmpWriter = FileWriter(tmp)
      tmpWriter.write(stream)
      tmpWriter.close()
      
      scriptReader = FileReader(tmp)
      
      feedback = File('feedback.log')
      feedbackWriter = FileWriter(feedback) 
      
      startupInfo = StartupInfoFactory.newStartupInfo()      
      
      properties = Properties()
      properties.setProperty(Processor.STDERR, feedbackWriter)
      properties.setProperty(Processor.STDIN,scriptReader)
      properties.setProperty(Processor.STDOUT, feedbackWriter)
      properties.setProperty(Processor.STARTUPINFO, startupInfo)
      properties.setProperty(Processor.ARGUMENT, ["mysql","--host="+str(mysqlHost),"--user="+str(mysqlUser),"--password="+str(mysqlPasswd),str(mysqlDatabase)])
      properties.setProperty(Processor.SHELL, False)
      mysqlCall= Call(properties)
            
      processor = Processor()
      processor.call(mysqlCall)
           
      logger = logging.getLogger('NoOraLogger')
      logger.info(mysqlScript)
    #except:
    #  logger = logging.getLogger('NoOraLogger')      
    #  if ignoreErrors==False:
    #    message = ""
    #    for info in sys.exc_info():
    #      message = message + str(info)

    #    logger.error(message)
    #    raise NooraException.NooraException(message)
    #  logger.info(stream)
      



import wx
import AbstractPanel as AbstractPanel
import gui.Settings  as Settings

class BrowsePanel(AbstractPanel.AbstractPanel):

  def getUrlTextControl(self):
    return self.__urlTextControl
  
  def getValue(self):
    urlTextControl=self.getUrlTextControl()
    return urlTextControl.GetValue()
  
  def setValue(self, value):
    urlTextControl=self.getUrlTextControl()
    urlTextControl.SetValue(value)

  def __init__(self, parent, id, label):
    AbstractPanel.AbstractPanel.__init__(self, parent, id)
    
    sizer=wx.BoxSizer(wx.HORIZONTAL) 
    self.__staticText = wx.StaticText(self, id, label)        
    self.__urlTextControl=wx.TextCtrl(self, id)
    self.__browseButton = wx.Button(self, Settings.ID_OPEN, "Browse") 

    width,height=self.__urlTextControl.GetSize().Get()       
    self.__staticText.SetMinSize((100,height))  
    
    sizer.Add(self.__staticText,0)     
    sizer.Add(self.__urlTextControl,1)
    sizer.Add(self.__browseButton,0)
    self.SetSizer(sizer)    



import wx
import AbstractPanel as AbstractPanel
import gui.Settings  as Settings

class ExecutePanel(AbstractPanel.AbstractPanel):

  def getExecuteButton(self):
    return self.__executeButton
  
  def getClearButton(self):
    return self.__clearButton

  def __init__(self, parent, id):
    AbstractPanel.AbstractPanel.__init__(self, parent, id)
    
    sizer=wx.BoxSizer(wx.HORIZONTAL)        
    self.__executeButton=wx.Button(self, Settings.ID_EXECUTE,"Execute") 
    self.__clearButton = wx.Button(self, Settings.ID_CLEAR,"Clear")  
    sizer.Add(self.__executeButton,0)
    sizer.Add(self.__clearButton,0)
    self.SetSizer(sizer)    



import wx
import os
import core.ClassLoader         as ClassLoader
import core.NooraException      as NooraException
import core.ParameterHelper     as ParameterHelper
import core.PluginFinishedEvent as PluginFinishedEvent
import core.PluginManager       as PluginManager
from threading import Thread

class PluginExecutionContext:
  
  def __init__(self, parent, id, plugin):
    self.__command = plugin.getType() 
    self.__plugin = plugin
    self.__parent = parent
    self.__id = id
    self.__parameterHelper=ParameterHelper.ParameterHelper()
    
  def getParameterHelper(self):
    return self.__parameterHelper
  
  def getPlugin(self):
    return self.__plugin
  
  def getParent(self):
    return self.__parent
  
  def getId(self):
    return self.__id
  
  def addExecutionParameter(self, parameter, value):
    if value:
      parameters=self.getParameterHelper().getParameters()
      parameterDefinitions=self.getPlugin().getParameterDefinitions()
      for parameterDefinition in parameterDefinitions:
        if parameterDefinition.getKey()==parameter:
          parameters.append(parameterDefinition.getFirstParameter()+"="+value)

class ExecuteThread(Thread):

  def __init__(self, executionContext):
    Thread.__init__(self)
    self.__executionContext=executionContext
    self.start()
    
  def getExecutionContext(self):
    return self.__executionContext
 
  def run(self):
    try:
      executionContext=self.getExecutionContext()
      plugin=executionContext.getPlugin()
      parameterHelper=executionContext.getParameterHelper()
      id=executionContext.getId()
      plugin.execute(parameterHelper)
      filename=plugin.getConfigReader().getFilename()
      wx.PostEvent(None, PluginFinishedEvent.PluginFinishedEvent(id, os.path.abspath('.'), filename))
    except NooraException.NooraException as e:      
      print e.getMessage()
      exit(1)


class CommandDispatcher:
  '''
  This class will invoke the specified command. It will read the project configuration and
  use the specified arguments to execute the correct plugin.
  '''
  def __init__(self, configReader):
    self.__pluginManager=PluginManager.PluginManager()
    self.setConfigReader(configReader)
    self.__parameterHelper=ParameterHelper.ParameterHelper()
  
  def getConfigReader(self):
    return self.__configReader

  def setConfigReader(self, configReader):
    self.__configReader=configReader
    self.loadPluginDefinitionsFromConfigReader()
    self.registerPlugins()

  def getParameterHelper(self):
    return self.__parameterHelper
  
  def setPluginManager(self, pluginManager):
    self.__pluginManager=pluginManager
    
  def getPluginManager(self):
    return self.__pluginManager
  
  def setPluginDefinitions(self, pluginDefinitions):
    ''' Sets the list of plugin definitions.
    '''
    self.__pluginDefinitions = pluginDefinitions  
  
  def getPluginDefinitions(self):
    return self.__pluginDefinitions
  
  def loadPluginDefinitionsFromConfigReader(self):
    ''' retrieves the plugin definitions using the ConfigReader.
    '''
    configReader=self.getConfigReader()
    self.setPluginDefinitions(configReader.getValue('PLUGINS'))
  
  def registerPlugins(self):
    classLoader = ClassLoader.ClassLoader()
    pluginManager = self.getPluginManager()
    pluginDefinitions = self.getPluginDefinitions()
    for pluginDefinition in pluginDefinitions:
      plugin=classLoader.findByPattern(pluginDefinition)
      pluginManager.registerPlugin(plugin)

  def getPluginTypes(self):
    pluginTypes=[]
    pluginManager = self.getPluginManager()
    plugins = pluginManager.getPlugins()
    for plugin in plugins:
      pluginTypes.append(plugin.getType().lower())
    return pluginTypes
        
  def getPlugin(self, type):
    pluginManager=self.getPluginManager()
    return pluginManager.findPlugin(type)

  def getPluginParameterDefinitions(self, type):
    plugin=self.getPlugin(type)
    return plugin.getParameterDefinitions()
        
  def createExecutionContext(self, parent, id, command):  
    plugin = self.getPlugin(command)  
    executionContext = PluginExecutionContext(parent, id, plugin)
    return executionContext
  
  def execute(self, executionContext):
    ExecuteThread(executionContext)
  

            

    

        


#!/usr/bin/env python

class PluginManager:
  
  def __init__(self):
    self.__plugins=[]

  def registerPlugin(self,plugin):
    self.__plugins.append(plugin)

  def getPlugins(self):
    return self.__plugins
  
  def findPlugin(self, type):
    plugins=self.getPlugins()
    for plugin in plugins:
      if plugin.getType().lower()==type.lower():
        return plugin
    return None
    
